@@ -1,4 +1,4 @@
-from .cls.bert_cls_classifier import *
+from .classification.bert_cls_classifier import *
 from .embedding.bert_embedding import *
 from .seq2seq.bert_seq2seq_model import *
 from .sequence_labeling.bert_sequence_labeling import *
\ No newline at end of file
